==> cx88-1.4.4.tar.gz: cx88-1.4.4/client/drivers/fusion_5gold.cpp <==
/*-
 * Copyright 2008 Konstantin Dimitrov <kosio.dimitrov@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include "lgh064f.h"
#include "lg3303.h"
#include "cx88_debug.h"
#include "fusion_5gold.h"

int fusion_5gold::create_i2c_drivers(void)
{
   int error = 0;
   cx88_common_gpio gpio;
   gpio.in_write_mask = 0x1;
   gpio.in_read_mask = 0x0;
   gpio.inout_gpio = 0x0;
   if ((error = ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0)
   {
      CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << std::endl;
      return error;
   }
   usleep(100000);
   gpio.in_write_mask = 0x1;
   gpio.in_read_mask = 0x0;
   gpio.inout_gpio = 0x1;
   if ((error = (ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0))
   {
      CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << std::endl;
      return error;  
   }
   usleep(200000);
   m_i2c_devs[0].driver = new lgh064f(m_tunerconf, *(m_i2c_devs[0].dev));
   m_i2c_devs[1].driver = new lg3303(m_tunerconf, *(m_i2c_devs[1].dev), DVB_IFC_NEG_POL, DVB_INPUT_SERIAL, error);
   if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
   {
      CX88ERR << "Error initializing tuner/demodulator driver for DViCO FusionHDTV 5 Gold" << std::endl;
      return ENOMEM;
   }
   return error;
}

void fusion_5gold::destroy_i2c_drivers(void)
{
   delete m_i2c_devs[1].driver;
   delete m_i2c_devs[0].driver;  
}

int fusion_5gold::create_i2c_devices(void)
{
   m_i2c_devs[0].conf.in_addr = 0x61;
   m_i2c_devs[1].conf.in_addr = 0x0e;
   return 0;
}

int fusion_5gold::set_capture_options(cx88_mpeg_capture &capture)
{
   capture.in_options = CX88_MPEG_SERIAL_INPUT | CX88_MPEG_BYTEWIDE_SOP;
   return 0;
}

==> cx88-1.4.6.tar.gz: cx88-1.4.6/client/drivers/fusion_5gold.cpp <==
/*-
 * Copyright 2008 Konstantin Dimitrov <kosio.dimitrov@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <new>
#include "lgh064f.h"
#include "lg3303.h"
#include "cx88_debug.h"
#include "fusion_5gold.h"

int fusion_5gold::create_i2c_drivers(void)
{
   int error = 0;
   cx88_common_gpio gpio;
   gpio.in_write_mask = 0x1;
   gpio.in_read_mask = 0x0;
   gpio.inout_gpio = 0x0;
   if ((error = ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0)
   {
      CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << std::endl;
      return error;
   }
   usleep(100000);
   gpio.in_write_mask = 0x1;
   gpio.in_read_mask = 0x0;
   gpio.inout_gpio = 0x1;
   if ((error = (ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0))
   {
      CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << std::endl;
      return error;  
   }
   usleep(200000);
   m_i2c_devs[0].driver = new(std::nothrow) lgh064f(m_tunerconf, *(m_i2c_devs[0].dev));
   m_i2c_devs[1].driver = new(std::nothrow) lg3303(m_tunerconf, *(m_i2c_devs[1].dev), DVB_IFC_NEG_POL, DVB_INPUT_SERIAL, error);
   if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
   {
      CX88ERR << "Error initializing tuner/demodulator driver for DViCO FusionHDTV 5 Gold" << std::endl;
      return ENOMEM;
   }
   return error;
}

void fusion_5gold::destroy_i2c_drivers(void)
{
   delete m_i2c_devs[1].driver;
   delete m_i2c_devs[0].driver;  
}

int fusion_5gold::create_i2c_devices(void)
{
   m_i2c_devs[0].conf.in_addr = 0x61;
   m_i2c_devs[1].conf.in_addr = 0x0e;
   return 0;
}

int fusion_5gold::set_capture_options(cx88_mpeg_capture &capture)
{
   capture.in_options = CX88_MPEG_SERIAL_INPUT | CX88_MPEG_BYTEWIDE_SOP;
   return 0;
}
